@@ -2,7 +2,7 @@
   +----------------------------------------------------------------------+
   | PHP Version 5                                                        |
   +----------------------------------------------------------------------+
-  | Copyright (c) 1997-2013 The PHP Group                                |
+  | Copyright (c) 1997-2016 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
@@ -16,7 +16,7 @@
   +----------------------------------------------------------------------+
 */
 
-/* $Id: e268047b695fe9a43cdf415c429729252347becd $ */
+/* $Id: 58590192720bc56939152fde3645d808b348bb9b $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -145,7 +145,7 @@ PHP_MINFO_FUNCTION(sysvmsg)
 {
 	php_info_print_table_start();
 	php_info_print_table_row(2, "sysvmsg support", "enabled");
-	php_info_print_table_row(2, "Revision", "$Id: e268047b695fe9a43cdf415c429729252347becd $");
+	php_info_print_table_row(2, "Revision", "$Id: 58590192720bc56939152fde3645d808b348bb9b $");
 	php_info_print_table_end();
 }
 /* }}} */
@@ -228,7 +228,7 @@ PHP_FUNCTION(msg_stat_queue)
 
 
 /* {{{ proto bool msg_queue_exists(int key)
-   Check wether a message queue exists */
+   Check whether a message queue exists */
 PHP_FUNCTION(msg_queue_exists)
 {
 	long key;
