@@ -243,7 +243,7 @@ XMLRPC_VALUE xml_element_to_SOAP_REQUEST_worker(XMLRPC_REQUEST request,
 		xCurrent = XMLRPC_CreateValueEmpty();
 	}
 
-	/* increment recursion depth guage */
+	/* increment recursion depth gauge */
 	depth ++;
 
 	/* safety first. must have a valid element */
@@ -279,7 +279,7 @@ XMLRPC_VALUE xml_element_to_SOAP_REQUEST_worker(XMLRPC_REQUEST request,
 			else if (!strcmp(attr_iter->key, TOKEN_MUSTUNDERSTAND)) {
 				b_must_understand = strchr(attr_iter->val, '1') ? 1 : 0;
 			}
-			/* actor, used in conjuction with must understand. */
+			/* actor, used in conjunction with must understand. */
 			else if (!strcmp(attr_iter->key, TOKEN_ACTOR)) {
 				actor = attr_iter->val;
 			}
@@ -379,7 +379,7 @@ XMLRPC_VALUE xml_element_to_SOAP_REQUEST_worker(XMLRPC_REQUEST request,
 			else if (!strcmp(type, TOKEN_ARRAY) || arrayType != NULL) {
 				/* determine magic associated with soap array type.
 				   this is passed down as we recurse, so our children have access to the info. */
-				ai = parse_array_type_info(arrayType);	// alloc'ed ai free'd below.
+				ai = parse_array_type_info(arrayType);	/* alloc'ed ai free'd below. */
 				XMLRPC_SetIsVector(xCurrent, xmlrpc_vector_array);
 			}
 			else {
